@@ -1,6 +1,9 @@
 #!/usr/bin/env python
 
 
+import json
+
+
 class Update(object):
     def __init__(self,
                  update_id,
@@ -18,3 +21,12 @@ class Update(object):
 
         return Update(update_id=data.get('update_id', None),
                       message=message)
+
+    def to_json(self):
+        json_data = {'update_id': self.update_id}
+        if self.message:
+            json_data['message'] = self.message.to_json()
+        return json.dumps(json_data)
+
+    def __str__(self):
+        return self.to_json()
